# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waterfront.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import column_type_pb2 as column__type__pb2
from . import data_room_pb2 as data__room__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='waterfront.proto',
  package='waterfront',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10waterfront.proto\x12\nwaterfront\x1a\x11\x63olumn_type.proto\x1a\x0f\x64\x61ta_room.proto\"\xdf\x07\n\x11WaterfrontRequest\x12\x36\n\x0fsqlQueryRequest\x18\x02 \x01(\x0b\x32\x1b.waterfront.SqlQueryRequestH\x00\x12\x42\n\x15\x63reateDataRoomRequest\x18\x05 \x01(\x0b\x32!.waterfront.CreateDataRoomRequestH\x00\x12V\n\x1fpublishDatasetToDataRoomRequest\x18\x06 \x01(\x0b\x32+.waterfront.PublishDatasetToDataRoomRequestH\x00\x12\x46\n\x17retrieveDataRoomRequest\x18\x07 \x01(\x0b\x32#.waterfront.RetrieveDataRoomRequestH\x00\x12\x44\n\x16validateDatasetRequest\x18\x08 \x01(\x0b\x32\".waterfront.ValidateDatasetRequestH\x00\x12\x46\n\x17retrieveAuditLogRequest\x18\t \x01(\x0b\x32#.waterfront.RetrieveAuditLogRequestH\x00\x12R\n\x1dretrieveDataRoomStatusRequest\x18\n \x01(\x0b\x32).waterfront.RetrieveDataRoomStatusRequestH\x00\x12N\n\x1bupdateDataRoomStatusRequest\x18\x0b \x01(\x0b\x32\'.waterfront.UpdateDataRoomStatusRequestH\x00\x12V\n\x1fretrievePublishedDatasetRequest\x18\x0c \x01(\x0b\x32+.waterfront.RetrievePublishedDatasetRequestH\x00\x12R\n\x1dremovePublishedDatasetRequest\x18\r \x01(\x0b\x32).waterfront.RemovePublishedDatasetRequestH\x00\x12\x38\n\x10jobStatusRequest\x18\x0e \x01(\x0b\x32\x1c.waterfront.JobStatusRequestH\x00\x12:\n\x11getResultsRequest\x18\x0f \x01(\x0b\x32\x1d.waterfront.GetResultsRequestH\x00\x12\x44\n\x16validateQueriesRequest\x18\x10 \x01(\x0b\x32\".waterfront.ValidateQueriesRequestH\x00\x42\x14\n\x12waterfront_request\"\xd0\x07\n\x12WaterfrontResponse\x12\x11\n\x07\x66\x61ilure\x18\x01 \x01(\tH\x00\x12\x38\n\x10sqlQueryResponse\x18\x03 \x01(\x0b\x32\x1c.waterfront.SqlQueryResponseH\x00\x12\x44\n\x16\x63reateDataRoomResponse\x18\x06 \x01(\x0b\x32\".waterfront.CreateDataRoomResponseH\x00\x12X\n publishDatasetToDataRoomResponse\x18\x07 \x01(\x0b\x32,.waterfront.PublishDatasetToDataRoomResponseH\x00\x12H\n\x18retrieveDataRoomResponse\x18\x08 \x01(\x0b\x32$.waterfront.RetrieveDataRoomResponseH\x00\x12\x46\n\x17validateDatasetResponse\x18\t \x01(\x0b\x32#.waterfront.ValidateDatasetResponseH\x00\x12H\n\x18retrieveAuditLogResponse\x18\n \x01(\x0b\x32$.waterfront.RetrieveAuditLogResponseH\x00\x12T\n\x1eretrieveDataRoomStatusResponse\x18\x0b \x01(\x0b\x32*.waterfront.RetrieveDataRoomStatusResponseH\x00\x12P\n\x1cupdateDataRoomStatusResponse\x18\x0c \x01(\x0b\x32(.waterfront.UpdateDataRoomStatusResponseH\x00\x12X\n retrievePublishedDatasetResponse\x18\r \x01(\x0b\x32,.waterfront.RetrievePublishedDatasetResponseH\x00\x12T\n\x1eremovePublishedDatasetResponse\x18\x0e \x01(\x0b\x32*.waterfront.RemovePublishedDatasetResponseH\x00\x12:\n\x11jobStatusResponse\x18\x0f \x01(\x0b\x32\x1d.waterfront.JobStatusResponseH\x00\x12\x46\n\x17validateQueriesResponse\x18\x10 \x01(\x0b\x32#.waterfront.ValidateQueriesResponseH\x00\x42\x15\n\x13waterfront_response\":\n\x12\x41uthenticationData\x12\x0c\n\x04role\x18\x01 \x02(\t\x12\x16\n\x0epasswordSha256\x18\x02 \x01(\t\">\n\x15\x43reateDataRoomRequest\x12%\n\x08\x64\x61taRoom\x18\x01 \x02(\x0b\x32\x13.data_room.DataRoom\"\x95\x01\n\x16\x43reateDataRoomResponse\x12\x16\n\x0c\x64\x61taRoomHash\x18\x01 \x01(\x0cH\x00\x12\x46\n\x17\x64\x61taRoomValidationError\x18\x02 \x01(\x0b\x32#.waterfront.DataRoomValidationErrorH\x00\x42\x1b\n\x19\x63reate_data_room_response\"\xac\x01\n\x17\x44\x61taRoomValidationError\x12\x0f\n\x07message\x18\x01 \x02(\t\x12\x12\n\nqueryIndex\x18\x02 \x01(\x04\x12\x13\n\x0b\x63olumnIndex\x18\x03 \x01(\x04\x12\x12\n\ntableIndex\x18\x04 \x01(\x04\x12\x11\n\troleIndex\x18\x05 \x01(\x04\x12\x17\n\x0fpermissionIndex\x18\x06 \x01(\x04\x12\x17\n\x0f\x63onstraintIndex\x18\x07 \x01(\x04\"\xc8\x01\n\x1fPublishDatasetToDataRoomRequest\x12\x14\n\x0cmanifestHash\x18\x01 \x02(\x0c\x12\x14\n\x0c\x64\x61taRoomHash\x18\x02 \x02(\x0c\x12\x19\n\x11\x64\x61taRoomTableName\x18\x03 \x02(\t\x12\x30\n\rencryptionKey\x18\x04 \x02(\x0b\x32\x19.waterfront.EncryptionKey\x12,\n\x04\x61uth\x18\x05 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\"\"\n PublishDatasetToDataRoomResponse\"`\n\x16ValidateDatasetRequest\x12\x14\n\x0cmanifestHash\x18\x01 \x02(\x0c\x12\x30\n\rencryptionKey\x18\x02 \x02(\x0b\x32\x19.waterfront.EncryptionKey\"6\n\x16ValidateDatasetFailure\x12\x0f\n\x07message\x18\x01 \x02(\t\x12\x0b\n\x03row\x18\x02 \x01(\x04\"N\n\x17ValidateDatasetResponse\x12\x33\n\x07\x66\x61ilure\x18\x01 \x01(\x0b\x32\".waterfront.ValidateDatasetFailure\"h\n\x0fSqlQueryRequest\x12\x11\n\tqueryName\x18\x01 \x02(\t\x12\x14\n\x0c\x64\x61taRoomHash\x18\x02 \x02(\x0c\x12,\n\x04\x61uth\x18\x05 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\"\x90\x01\n\x10SqlQueryResponse\x12\x34\n\ninProgress\x18\x01 \x01(\x0b\x32\x1e.waterfront.SqlQueryInProgressH\x00\x12\x30\n\x08\x66inished\x18\x02 \x01(\x0b\x32\x1c.waterfront.SqlQueryFinishedH\x00\x42\x14\n\x12sql_query_response\"#\n\x12SqlQueryInProgress\x12\r\n\x05jobId\x18\x01 \x02(\x0c\"0\n\x10SqlQueryFinished\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\x0e\n\x06header\x18\x02 \x03(\t\"O\n\x10JobStatusRequest\x12\r\n\x05jobId\x18\x01 \x02(\x0c\x12,\n\x04\x61uth\x18\x02 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\"&\n\x11JobStatusResponse\x12\x11\n\tcompleted\x18\x01 \x02(\x08\"P\n\x11GetResultsRequest\x12\r\n\x05jobId\x18\x01 \x02(\x0c\x12,\n\x04\x61uth\x18\x02 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\"]\n\x17RetrieveDataRoomRequest\x12\x14\n\x0c\x64\x61taRoomHash\x18\x01 \x02(\x0c\x12,\n\x04\x61uth\x18\x05 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\"A\n\x18RetrieveDataRoomResponse\x12%\n\x08\x64\x61taRoom\x18\x01 \x02(\x0b\x32\x13.data_room.DataRoom\"]\n\x17RetrieveAuditLogRequest\x12\x14\n\x0c\x64\x61taRoomHash\x18\x01 \x02(\x0c\x12,\n\x04\x61uth\x18\x02 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\"(\n\x18RetrieveAuditLogResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"c\n\x1dRetrieveDataRoomStatusRequest\x12\x14\n\x0c\x64\x61taRoomHash\x18\x01 \x02(\x0c\x12,\n\x04\x61uth\x18\x02 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\"L\n\x1eRetrieveDataRoomStatusResponse\x12*\n\x06status\x18\x01 \x02(\x0e\x32\x1a.waterfront.DataRoomStatus\"\x8d\x01\n\x1bUpdateDataRoomStatusRequest\x12\x14\n\x0c\x64\x61taRoomHash\x18\x01 \x02(\x0c\x12,\n\x04\x61uth\x18\x02 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\x12*\n\x06status\x18\x03 \x02(\x0e\x32\x1a.waterfront.DataRoomStatus\"\x1e\n\x1cUpdateDataRoomStatusResponse\"e\n\x1fRetrievePublishedDatasetRequest\x12\x14\n\x0c\x64\x61taRoomHash\x18\x01 \x02(\x0c\x12,\n\x04\x61uth\x18\x02 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\"X\n\x10PublishedDataset\x12\r\n\x05table\x18\x01 \x02(\t\x12\x0c\n\x04user\x18\x02 \x02(\t\x12\x11\n\ttimestamp\x18\x03 \x02(\x04\x12\x14\n\x0c\x64\x61taset_hash\x18\x04 \x02(\x0c\"[\n RetrievePublishedDatasetResponse\x12\x37\n\x11publishedDatasets\x18\x01 \x03(\x0b\x32\x1c.waterfront.PublishedDataset\"\x94\x01\n\x1dRemovePublishedDatasetRequest\x12\x14\n\x0cmanifestHash\x18\x01 \x02(\x0c\x12\x14\n\x0c\x64\x61taRoomHash\x18\x02 \x02(\x0c\x12\x19\n\x11\x64\x61taRoomTableName\x18\x03 \x02(\t\x12,\n\x04\x61uth\x18\x04 \x02(\x0b\x32\x1e.waterfront.AuthenticationData\" \n\x1eRemovePublishedDatasetResponse\"?\n\x16ValidateQueriesRequest\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\"=\n\x0cQuerySchemas\x12-\n\x0ctableSchemas\x18\x01 \x03(\x0b\x32\x17.waterfront.TableSchema\"\xb0\x01\n\x17ValidateQueriesResponse\x12\x30\n\x0cquerySchemas\x18\x01 \x01(\x0b\x32\x18.waterfront.QuerySchemasH\x00\x12\x46\n\x17\x64\x61taRoomValidationError\x18\x02 \x01(\x0b\x32#.waterfront.DataRoomValidationErrorH\x00\x42\x1b\n\x19validate_queries_response\"/\n\rEncryptionKey\x12\x10\n\x08material\x18\x01 \x02(\x0c\x12\x0c\n\x04salt\x18\x02 \x02(\x0c\"<\n\x0bTableSchema\x12-\n\x0cnamedColumns\x18\x01 \x03(\x0b\x32\x17.waterfront.NamedColumn\"H\n\x0bNamedColumn\x12\x0c\n\x04name\x18\x01 \x02(\t\x12+\n\ncolumnType\x18\x02 \x02(\x0b\x32\x17.column_type.ColumnType\"N\n\x0f\x44\x61tasetManifest\x12\x12\n\ndigestHash\x18\x01 \x02(\x0c\x12\'\n\x06schema\x18\x02 \x02(\x0b\x32\x17.waterfront.TableSchema*)\n\x0e\x44\x61taRoomStatus\x12\n\n\x06\x41\x63tive\x10\x01\x12\x0b\n\x07Stopped\x10\x02'
  ,
  dependencies=[column__type__pb2.DESCRIPTOR,data__room__pb2.DESCRIPTOR,])

_DATAROOMSTATUS = _descriptor.EnumDescriptor(
  name='DataRoomStatus',
  full_name='waterfront.DataRoomStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Active', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Stopped', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5205,
  serialized_end=5246,
)
_sym_db.RegisterEnumDescriptor(_DATAROOMSTATUS)

DataRoomStatus = enum_type_wrapper.EnumTypeWrapper(_DATAROOMSTATUS)
Active = 1
Stopped = 2



_WATERFRONTREQUEST = _descriptor.Descriptor(
  name='WaterfrontRequest',
  full_name='waterfront.WaterfrontRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sqlQueryRequest', full_name='waterfront.WaterfrontRequest.sqlQueryRequest', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createDataRoomRequest', full_name='waterfront.WaterfrontRequest.createDataRoomRequest', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishDatasetToDataRoomRequest', full_name='waterfront.WaterfrontRequest.publishDatasetToDataRoomRequest', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieveDataRoomRequest', full_name='waterfront.WaterfrontRequest.retrieveDataRoomRequest', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validateDatasetRequest', full_name='waterfront.WaterfrontRequest.validateDatasetRequest', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieveAuditLogRequest', full_name='waterfront.WaterfrontRequest.retrieveAuditLogRequest', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieveDataRoomStatusRequest', full_name='waterfront.WaterfrontRequest.retrieveDataRoomStatusRequest', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateDataRoomStatusRequest', full_name='waterfront.WaterfrontRequest.updateDataRoomStatusRequest', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrievePublishedDatasetRequest', full_name='waterfront.WaterfrontRequest.retrievePublishedDatasetRequest', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='removePublishedDatasetRequest', full_name='waterfront.WaterfrontRequest.removePublishedDatasetRequest', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobStatusRequest', full_name='waterfront.WaterfrontRequest.jobStatusRequest', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getResultsRequest', full_name='waterfront.WaterfrontRequest.getResultsRequest', index=11,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validateQueriesRequest', full_name='waterfront.WaterfrontRequest.validateQueriesRequest', index=12,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='waterfront_request', full_name='waterfront.WaterfrontRequest.waterfront_request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=69,
  serialized_end=1060,
)


_WATERFRONTRESPONSE = _descriptor.Descriptor(
  name='WaterfrontResponse',
  full_name='waterfront.WaterfrontResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='failure', full_name='waterfront.WaterfrontResponse.failure', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sqlQueryResponse', full_name='waterfront.WaterfrontResponse.sqlQueryResponse', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createDataRoomResponse', full_name='waterfront.WaterfrontResponse.createDataRoomResponse', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishDatasetToDataRoomResponse', full_name='waterfront.WaterfrontResponse.publishDatasetToDataRoomResponse', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieveDataRoomResponse', full_name='waterfront.WaterfrontResponse.retrieveDataRoomResponse', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validateDatasetResponse', full_name='waterfront.WaterfrontResponse.validateDatasetResponse', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieveAuditLogResponse', full_name='waterfront.WaterfrontResponse.retrieveAuditLogResponse', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieveDataRoomStatusResponse', full_name='waterfront.WaterfrontResponse.retrieveDataRoomStatusResponse', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateDataRoomStatusResponse', full_name='waterfront.WaterfrontResponse.updateDataRoomStatusResponse', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrievePublishedDatasetResponse', full_name='waterfront.WaterfrontResponse.retrievePublishedDatasetResponse', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='removePublishedDatasetResponse', full_name='waterfront.WaterfrontResponse.removePublishedDatasetResponse', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobStatusResponse', full_name='waterfront.WaterfrontResponse.jobStatusResponse', index=11,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validateQueriesResponse', full_name='waterfront.WaterfrontResponse.validateQueriesResponse', index=12,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='waterfront_response', full_name='waterfront.WaterfrontResponse.waterfront_response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1063,
  serialized_end=2039,
)


_AUTHENTICATIONDATA = _descriptor.Descriptor(
  name='AuthenticationData',
  full_name='waterfront.AuthenticationData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role', full_name='waterfront.AuthenticationData.role', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passwordSha256', full_name='waterfront.AuthenticationData.passwordSha256', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2041,
  serialized_end=2099,
)


_CREATEDATAROOMREQUEST = _descriptor.Descriptor(
  name='CreateDataRoomRequest',
  full_name='waterfront.CreateDataRoomRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataRoom', full_name='waterfront.CreateDataRoomRequest.dataRoom', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2101,
  serialized_end=2163,
)


_CREATEDATAROOMRESPONSE = _descriptor.Descriptor(
  name='CreateDataRoomResponse',
  full_name='waterfront.CreateDataRoomResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataRoomHash', full_name='waterfront.CreateDataRoomResponse.dataRoomHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataRoomValidationError', full_name='waterfront.CreateDataRoomResponse.dataRoomValidationError', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='create_data_room_response', full_name='waterfront.CreateDataRoomResponse.create_data_room_response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2166,
  serialized_end=2315,
)


_DATAROOMVALIDATIONERROR = _descriptor.Descriptor(
  name='DataRoomValidationError',
  full_name='waterfront.DataRoomValidationError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='waterfront.DataRoomValidationError.message', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queryIndex', full_name='waterfront.DataRoomValidationError.queryIndex', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columnIndex', full_name='waterfront.DataRoomValidationError.columnIndex', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tableIndex', full_name='waterfront.DataRoomValidationError.tableIndex', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roleIndex', full_name='waterfront.DataRoomValidationError.roleIndex', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissionIndex', full_name='waterfront.DataRoomValidationError.permissionIndex', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraintIndex', full_name='waterfront.DataRoomValidationError.constraintIndex', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2318,
  serialized_end=2490,
)


_PUBLISHDATASETTODATAROOMREQUEST = _descriptor.Descriptor(
  name='PublishDatasetToDataRoomRequest',
  full_name='waterfront.PublishDatasetToDataRoomRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manifestHash', full_name='waterfront.PublishDatasetToDataRoomRequest.manifestHash', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataRoomHash', full_name='waterfront.PublishDatasetToDataRoomRequest.dataRoomHash', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataRoomTableName', full_name='waterfront.PublishDatasetToDataRoomRequest.dataRoomTableName', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryptionKey', full_name='waterfront.PublishDatasetToDataRoomRequest.encryptionKey', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.PublishDatasetToDataRoomRequest.auth', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2493,
  serialized_end=2693,
)


_PUBLISHDATASETTODATAROOMRESPONSE = _descriptor.Descriptor(
  name='PublishDatasetToDataRoomResponse',
  full_name='waterfront.PublishDatasetToDataRoomResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2695,
  serialized_end=2729,
)


_VALIDATEDATASETREQUEST = _descriptor.Descriptor(
  name='ValidateDatasetRequest',
  full_name='waterfront.ValidateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manifestHash', full_name='waterfront.ValidateDatasetRequest.manifestHash', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryptionKey', full_name='waterfront.ValidateDatasetRequest.encryptionKey', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2731,
  serialized_end=2827,
)


_VALIDATEDATASETFAILURE = _descriptor.Descriptor(
  name='ValidateDatasetFailure',
  full_name='waterfront.ValidateDatasetFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='waterfront.ValidateDatasetFailure.message', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='row', full_name='waterfront.ValidateDatasetFailure.row', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2829,
  serialized_end=2883,
)


_VALIDATEDATASETRESPONSE = _descriptor.Descriptor(
  name='ValidateDatasetResponse',
  full_name='waterfront.ValidateDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='failure', full_name='waterfront.ValidateDatasetResponse.failure', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2885,
  serialized_end=2963,
)


_SQLQUERYREQUEST = _descriptor.Descriptor(
  name='SqlQueryRequest',
  full_name='waterfront.SqlQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queryName', full_name='waterfront.SqlQueryRequest.queryName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataRoomHash', full_name='waterfront.SqlQueryRequest.dataRoomHash', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.SqlQueryRequest.auth', index=2,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2965,
  serialized_end=3069,
)


_SQLQUERYRESPONSE = _descriptor.Descriptor(
  name='SqlQueryResponse',
  full_name='waterfront.SqlQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inProgress', full_name='waterfront.SqlQueryResponse.inProgress', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished', full_name='waterfront.SqlQueryResponse.finished', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sql_query_response', full_name='waterfront.SqlQueryResponse.sql_query_response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3072,
  serialized_end=3216,
)


_SQLQUERYINPROGRESS = _descriptor.Descriptor(
  name='SqlQueryInProgress',
  full_name='waterfront.SqlQueryInProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='waterfront.SqlQueryInProgress.jobId', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3218,
  serialized_end=3253,
)


_SQLQUERYFINISHED = _descriptor.Descriptor(
  name='SqlQueryFinished',
  full_name='waterfront.SqlQueryFinished',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='waterfront.SqlQueryFinished.data', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='waterfront.SqlQueryFinished.header', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3255,
  serialized_end=3303,
)


_JOBSTATUSREQUEST = _descriptor.Descriptor(
  name='JobStatusRequest',
  full_name='waterfront.JobStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='waterfront.JobStatusRequest.jobId', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.JobStatusRequest.auth', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3305,
  serialized_end=3384,
)


_JOBSTATUSRESPONSE = _descriptor.Descriptor(
  name='JobStatusResponse',
  full_name='waterfront.JobStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='completed', full_name='waterfront.JobStatusResponse.completed', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3386,
  serialized_end=3424,
)


_GETRESULTSREQUEST = _descriptor.Descriptor(
  name='GetResultsRequest',
  full_name='waterfront.GetResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='waterfront.GetResultsRequest.jobId', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.GetResultsRequest.auth', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3426,
  serialized_end=3506,
)


_RETRIEVEDATAROOMREQUEST = _descriptor.Descriptor(
  name='RetrieveDataRoomRequest',
  full_name='waterfront.RetrieveDataRoomRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataRoomHash', full_name='waterfront.RetrieveDataRoomRequest.dataRoomHash', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.RetrieveDataRoomRequest.auth', index=1,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3508,
  serialized_end=3601,
)


_RETRIEVEDATAROOMRESPONSE = _descriptor.Descriptor(
  name='RetrieveDataRoomResponse',
  full_name='waterfront.RetrieveDataRoomResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataRoom', full_name='waterfront.RetrieveDataRoomResponse.dataRoom', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3603,
  serialized_end=3668,
)


_RETRIEVEAUDITLOGREQUEST = _descriptor.Descriptor(
  name='RetrieveAuditLogRequest',
  full_name='waterfront.RetrieveAuditLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataRoomHash', full_name='waterfront.RetrieveAuditLogRequest.dataRoomHash', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.RetrieveAuditLogRequest.auth', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3670,
  serialized_end=3763,
)


_RETRIEVEAUDITLOGRESPONSE = _descriptor.Descriptor(
  name='RetrieveAuditLogResponse',
  full_name='waterfront.RetrieveAuditLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='waterfront.RetrieveAuditLogResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3765,
  serialized_end=3805,
)


_RETRIEVEDATAROOMSTATUSREQUEST = _descriptor.Descriptor(
  name='RetrieveDataRoomStatusRequest',
  full_name='waterfront.RetrieveDataRoomStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataRoomHash', full_name='waterfront.RetrieveDataRoomStatusRequest.dataRoomHash', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.RetrieveDataRoomStatusRequest.auth', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3807,
  serialized_end=3906,
)


_RETRIEVEDATAROOMSTATUSRESPONSE = _descriptor.Descriptor(
  name='RetrieveDataRoomStatusResponse',
  full_name='waterfront.RetrieveDataRoomStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='waterfront.RetrieveDataRoomStatusResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3908,
  serialized_end=3984,
)


_UPDATEDATAROOMSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateDataRoomStatusRequest',
  full_name='waterfront.UpdateDataRoomStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataRoomHash', full_name='waterfront.UpdateDataRoomStatusRequest.dataRoomHash', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.UpdateDataRoomStatusRequest.auth', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='waterfront.UpdateDataRoomStatusRequest.status', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3987,
  serialized_end=4128,
)


_UPDATEDATAROOMSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateDataRoomStatusResponse',
  full_name='waterfront.UpdateDataRoomStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4130,
  serialized_end=4160,
)


_RETRIEVEPUBLISHEDDATASETREQUEST = _descriptor.Descriptor(
  name='RetrievePublishedDatasetRequest',
  full_name='waterfront.RetrievePublishedDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataRoomHash', full_name='waterfront.RetrievePublishedDatasetRequest.dataRoomHash', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.RetrievePublishedDatasetRequest.auth', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4162,
  serialized_end=4263,
)


_PUBLISHEDDATASET = _descriptor.Descriptor(
  name='PublishedDataset',
  full_name='waterfront.PublishedDataset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='waterfront.PublishedDataset.table', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='waterfront.PublishedDataset.user', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='waterfront.PublishedDataset.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset_hash', full_name='waterfront.PublishedDataset.dataset_hash', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4265,
  serialized_end=4353,
)


_RETRIEVEPUBLISHEDDATASETRESPONSE = _descriptor.Descriptor(
  name='RetrievePublishedDatasetResponse',
  full_name='waterfront.RetrievePublishedDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedDatasets', full_name='waterfront.RetrievePublishedDatasetResponse.publishedDatasets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4355,
  serialized_end=4446,
)


_REMOVEPUBLISHEDDATASETREQUEST = _descriptor.Descriptor(
  name='RemovePublishedDatasetRequest',
  full_name='waterfront.RemovePublishedDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manifestHash', full_name='waterfront.RemovePublishedDatasetRequest.manifestHash', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataRoomHash', full_name='waterfront.RemovePublishedDatasetRequest.dataRoomHash', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataRoomTableName', full_name='waterfront.RemovePublishedDatasetRequest.dataRoomTableName', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='waterfront.RemovePublishedDatasetRequest.auth', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4449,
  serialized_end=4597,
)


_REMOVEPUBLISHEDDATASETRESPONSE = _descriptor.Descriptor(
  name='RemovePublishedDatasetResponse',
  full_name='waterfront.RemovePublishedDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4599,
  serialized_end=4631,
)


_VALIDATEQUERIESREQUEST = _descriptor.Descriptor(
  name='ValidateQueriesRequest',
  full_name='waterfront.ValidateQueriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataRoom', full_name='waterfront.ValidateQueriesRequest.dataRoom', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4633,
  serialized_end=4696,
)


_QUERYSCHEMAS = _descriptor.Descriptor(
  name='QuerySchemas',
  full_name='waterfront.QuerySchemas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tableSchemas', full_name='waterfront.QuerySchemas.tableSchemas', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4698,
  serialized_end=4759,
)


_VALIDATEQUERIESRESPONSE = _descriptor.Descriptor(
  name='ValidateQueriesResponse',
  full_name='waterfront.ValidateQueriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='querySchemas', full_name='waterfront.ValidateQueriesResponse.querySchemas', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataRoomValidationError', full_name='waterfront.ValidateQueriesResponse.dataRoomValidationError', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='validate_queries_response', full_name='waterfront.ValidateQueriesResponse.validate_queries_response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4762,
  serialized_end=4938,
)


_ENCRYPTIONKEY = _descriptor.Descriptor(
  name='EncryptionKey',
  full_name='waterfront.EncryptionKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='material', full_name='waterfront.EncryptionKey.material', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='salt', full_name='waterfront.EncryptionKey.salt', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4940,
  serialized_end=4987,
)


_TABLESCHEMA = _descriptor.Descriptor(
  name='TableSchema',
  full_name='waterfront.TableSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namedColumns', full_name='waterfront.TableSchema.namedColumns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4989,
  serialized_end=5049,
)


_NAMEDCOLUMN = _descriptor.Descriptor(
  name='NamedColumn',
  full_name='waterfront.NamedColumn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='waterfront.NamedColumn.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columnType', full_name='waterfront.NamedColumn.columnType', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5051,
  serialized_end=5123,
)


_DATASETMANIFEST = _descriptor.Descriptor(
  name='DatasetManifest',
  full_name='waterfront.DatasetManifest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='digestHash', full_name='waterfront.DatasetManifest.digestHash', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='waterfront.DatasetManifest.schema', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5125,
  serialized_end=5203,
)

_WATERFRONTREQUEST.fields_by_name['sqlQueryRequest'].message_type = _SQLQUERYREQUEST
_WATERFRONTREQUEST.fields_by_name['createDataRoomRequest'].message_type = _CREATEDATAROOMREQUEST
_WATERFRONTREQUEST.fields_by_name['publishDatasetToDataRoomRequest'].message_type = _PUBLISHDATASETTODATAROOMREQUEST
_WATERFRONTREQUEST.fields_by_name['retrieveDataRoomRequest'].message_type = _RETRIEVEDATAROOMREQUEST
_WATERFRONTREQUEST.fields_by_name['validateDatasetRequest'].message_type = _VALIDATEDATASETREQUEST
_WATERFRONTREQUEST.fields_by_name['retrieveAuditLogRequest'].message_type = _RETRIEVEAUDITLOGREQUEST
_WATERFRONTREQUEST.fields_by_name['retrieveDataRoomStatusRequest'].message_type = _RETRIEVEDATAROOMSTATUSREQUEST
_WATERFRONTREQUEST.fields_by_name['updateDataRoomStatusRequest'].message_type = _UPDATEDATAROOMSTATUSREQUEST
_WATERFRONTREQUEST.fields_by_name['retrievePublishedDatasetRequest'].message_type = _RETRIEVEPUBLISHEDDATASETREQUEST
_WATERFRONTREQUEST.fields_by_name['removePublishedDatasetRequest'].message_type = _REMOVEPUBLISHEDDATASETREQUEST
_WATERFRONTREQUEST.fields_by_name['jobStatusRequest'].message_type = _JOBSTATUSREQUEST
_WATERFRONTREQUEST.fields_by_name['getResultsRequest'].message_type = _GETRESULTSREQUEST
_WATERFRONTREQUEST.fields_by_name['validateQueriesRequest'].message_type = _VALIDATEQUERIESREQUEST
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['sqlQueryRequest'])
_WATERFRONTREQUEST.fields_by_name['sqlQueryRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['createDataRoomRequest'])
_WATERFRONTREQUEST.fields_by_name['createDataRoomRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['publishDatasetToDataRoomRequest'])
_WATERFRONTREQUEST.fields_by_name['publishDatasetToDataRoomRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['retrieveDataRoomRequest'])
_WATERFRONTREQUEST.fields_by_name['retrieveDataRoomRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['validateDatasetRequest'])
_WATERFRONTREQUEST.fields_by_name['validateDatasetRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['retrieveAuditLogRequest'])
_WATERFRONTREQUEST.fields_by_name['retrieveAuditLogRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['retrieveDataRoomStatusRequest'])
_WATERFRONTREQUEST.fields_by_name['retrieveDataRoomStatusRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['updateDataRoomStatusRequest'])
_WATERFRONTREQUEST.fields_by_name['updateDataRoomStatusRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['retrievePublishedDatasetRequest'])
_WATERFRONTREQUEST.fields_by_name['retrievePublishedDatasetRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['removePublishedDatasetRequest'])
_WATERFRONTREQUEST.fields_by_name['removePublishedDatasetRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['jobStatusRequest'])
_WATERFRONTREQUEST.fields_by_name['jobStatusRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['getResultsRequest'])
_WATERFRONTREQUEST.fields_by_name['getResultsRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTREQUEST.oneofs_by_name['waterfront_request'].fields.append(
  _WATERFRONTREQUEST.fields_by_name['validateQueriesRequest'])
_WATERFRONTREQUEST.fields_by_name['validateQueriesRequest'].containing_oneof = _WATERFRONTREQUEST.oneofs_by_name['waterfront_request']
_WATERFRONTRESPONSE.fields_by_name['sqlQueryResponse'].message_type = _SQLQUERYRESPONSE
_WATERFRONTRESPONSE.fields_by_name['createDataRoomResponse'].message_type = _CREATEDATAROOMRESPONSE
_WATERFRONTRESPONSE.fields_by_name['publishDatasetToDataRoomResponse'].message_type = _PUBLISHDATASETTODATAROOMRESPONSE
_WATERFRONTRESPONSE.fields_by_name['retrieveDataRoomResponse'].message_type = _RETRIEVEDATAROOMRESPONSE
_WATERFRONTRESPONSE.fields_by_name['validateDatasetResponse'].message_type = _VALIDATEDATASETRESPONSE
_WATERFRONTRESPONSE.fields_by_name['retrieveAuditLogResponse'].message_type = _RETRIEVEAUDITLOGRESPONSE
_WATERFRONTRESPONSE.fields_by_name['retrieveDataRoomStatusResponse'].message_type = _RETRIEVEDATAROOMSTATUSRESPONSE
_WATERFRONTRESPONSE.fields_by_name['updateDataRoomStatusResponse'].message_type = _UPDATEDATAROOMSTATUSRESPONSE
_WATERFRONTRESPONSE.fields_by_name['retrievePublishedDatasetResponse'].message_type = _RETRIEVEPUBLISHEDDATASETRESPONSE
_WATERFRONTRESPONSE.fields_by_name['removePublishedDatasetResponse'].message_type = _REMOVEPUBLISHEDDATASETRESPONSE
_WATERFRONTRESPONSE.fields_by_name['jobStatusResponse'].message_type = _JOBSTATUSRESPONSE
_WATERFRONTRESPONSE.fields_by_name['validateQueriesResponse'].message_type = _VALIDATEQUERIESRESPONSE
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['failure'])
_WATERFRONTRESPONSE.fields_by_name['failure'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['sqlQueryResponse'])
_WATERFRONTRESPONSE.fields_by_name['sqlQueryResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['createDataRoomResponse'])
_WATERFRONTRESPONSE.fields_by_name['createDataRoomResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['publishDatasetToDataRoomResponse'])
_WATERFRONTRESPONSE.fields_by_name['publishDatasetToDataRoomResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['retrieveDataRoomResponse'])
_WATERFRONTRESPONSE.fields_by_name['retrieveDataRoomResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['validateDatasetResponse'])
_WATERFRONTRESPONSE.fields_by_name['validateDatasetResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['retrieveAuditLogResponse'])
_WATERFRONTRESPONSE.fields_by_name['retrieveAuditLogResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['retrieveDataRoomStatusResponse'])
_WATERFRONTRESPONSE.fields_by_name['retrieveDataRoomStatusResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['updateDataRoomStatusResponse'])
_WATERFRONTRESPONSE.fields_by_name['updateDataRoomStatusResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['retrievePublishedDatasetResponse'])
_WATERFRONTRESPONSE.fields_by_name['retrievePublishedDatasetResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['removePublishedDatasetResponse'])
_WATERFRONTRESPONSE.fields_by_name['removePublishedDatasetResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['jobStatusResponse'])
_WATERFRONTRESPONSE.fields_by_name['jobStatusResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_WATERFRONTRESPONSE.oneofs_by_name['waterfront_response'].fields.append(
  _WATERFRONTRESPONSE.fields_by_name['validateQueriesResponse'])
_WATERFRONTRESPONSE.fields_by_name['validateQueriesResponse'].containing_oneof = _WATERFRONTRESPONSE.oneofs_by_name['waterfront_response']
_CREATEDATAROOMREQUEST.fields_by_name['dataRoom'].message_type = data__room__pb2._DATAROOM
_CREATEDATAROOMRESPONSE.fields_by_name['dataRoomValidationError'].message_type = _DATAROOMVALIDATIONERROR
_CREATEDATAROOMRESPONSE.oneofs_by_name['create_data_room_response'].fields.append(
  _CREATEDATAROOMRESPONSE.fields_by_name['dataRoomHash'])
_CREATEDATAROOMRESPONSE.fields_by_name['dataRoomHash'].containing_oneof = _CREATEDATAROOMRESPONSE.oneofs_by_name['create_data_room_response']
_CREATEDATAROOMRESPONSE.oneofs_by_name['create_data_room_response'].fields.append(
  _CREATEDATAROOMRESPONSE.fields_by_name['dataRoomValidationError'])
_CREATEDATAROOMRESPONSE.fields_by_name['dataRoomValidationError'].containing_oneof = _CREATEDATAROOMRESPONSE.oneofs_by_name['create_data_room_response']
_PUBLISHDATASETTODATAROOMREQUEST.fields_by_name['encryptionKey'].message_type = _ENCRYPTIONKEY
_PUBLISHDATASETTODATAROOMREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_VALIDATEDATASETREQUEST.fields_by_name['encryptionKey'].message_type = _ENCRYPTIONKEY
_VALIDATEDATASETRESPONSE.fields_by_name['failure'].message_type = _VALIDATEDATASETFAILURE
_SQLQUERYREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_SQLQUERYRESPONSE.fields_by_name['inProgress'].message_type = _SQLQUERYINPROGRESS
_SQLQUERYRESPONSE.fields_by_name['finished'].message_type = _SQLQUERYFINISHED
_SQLQUERYRESPONSE.oneofs_by_name['sql_query_response'].fields.append(
  _SQLQUERYRESPONSE.fields_by_name['inProgress'])
_SQLQUERYRESPONSE.fields_by_name['inProgress'].containing_oneof = _SQLQUERYRESPONSE.oneofs_by_name['sql_query_response']
_SQLQUERYRESPONSE.oneofs_by_name['sql_query_response'].fields.append(
  _SQLQUERYRESPONSE.fields_by_name['finished'])
_SQLQUERYRESPONSE.fields_by_name['finished'].containing_oneof = _SQLQUERYRESPONSE.oneofs_by_name['sql_query_response']
_JOBSTATUSREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_GETRESULTSREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_RETRIEVEDATAROOMREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_RETRIEVEDATAROOMRESPONSE.fields_by_name['dataRoom'].message_type = data__room__pb2._DATAROOM
_RETRIEVEAUDITLOGREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_RETRIEVEDATAROOMSTATUSREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_RETRIEVEDATAROOMSTATUSRESPONSE.fields_by_name['status'].enum_type = _DATAROOMSTATUS
_UPDATEDATAROOMSTATUSREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_UPDATEDATAROOMSTATUSREQUEST.fields_by_name['status'].enum_type = _DATAROOMSTATUS
_RETRIEVEPUBLISHEDDATASETREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_RETRIEVEPUBLISHEDDATASETRESPONSE.fields_by_name['publishedDatasets'].message_type = _PUBLISHEDDATASET
_REMOVEPUBLISHEDDATASETREQUEST.fields_by_name['auth'].message_type = _AUTHENTICATIONDATA
_VALIDATEQUERIESREQUEST.fields_by_name['dataRoom'].message_type = data__room__pb2._DATAROOM
_QUERYSCHEMAS.fields_by_name['tableSchemas'].message_type = _TABLESCHEMA
_VALIDATEQUERIESRESPONSE.fields_by_name['querySchemas'].message_type = _QUERYSCHEMAS
_VALIDATEQUERIESRESPONSE.fields_by_name['dataRoomValidationError'].message_type = _DATAROOMVALIDATIONERROR
_VALIDATEQUERIESRESPONSE.oneofs_by_name['validate_queries_response'].fields.append(
  _VALIDATEQUERIESRESPONSE.fields_by_name['querySchemas'])
_VALIDATEQUERIESRESPONSE.fields_by_name['querySchemas'].containing_oneof = _VALIDATEQUERIESRESPONSE.oneofs_by_name['validate_queries_response']
_VALIDATEQUERIESRESPONSE.oneofs_by_name['validate_queries_response'].fields.append(
  _VALIDATEQUERIESRESPONSE.fields_by_name['dataRoomValidationError'])
_VALIDATEQUERIESRESPONSE.fields_by_name['dataRoomValidationError'].containing_oneof = _VALIDATEQUERIESRESPONSE.oneofs_by_name['validate_queries_response']
_TABLESCHEMA.fields_by_name['namedColumns'].message_type = _NAMEDCOLUMN
_NAMEDCOLUMN.fields_by_name['columnType'].message_type = column__type__pb2._COLUMNTYPE
_DATASETMANIFEST.fields_by_name['schema'].message_type = _TABLESCHEMA
DESCRIPTOR.message_types_by_name['WaterfrontRequest'] = _WATERFRONTREQUEST
DESCRIPTOR.message_types_by_name['WaterfrontResponse'] = _WATERFRONTRESPONSE
DESCRIPTOR.message_types_by_name['AuthenticationData'] = _AUTHENTICATIONDATA
DESCRIPTOR.message_types_by_name['CreateDataRoomRequest'] = _CREATEDATAROOMREQUEST
DESCRIPTOR.message_types_by_name['CreateDataRoomResponse'] = _CREATEDATAROOMRESPONSE
DESCRIPTOR.message_types_by_name['DataRoomValidationError'] = _DATAROOMVALIDATIONERROR
DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomRequest'] = _PUBLISHDATASETTODATAROOMREQUEST
DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomResponse'] = _PUBLISHDATASETTODATAROOMRESPONSE
DESCRIPTOR.message_types_by_name['ValidateDatasetRequest'] = _VALIDATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['ValidateDatasetFailure'] = _VALIDATEDATASETFAILURE
DESCRIPTOR.message_types_by_name['ValidateDatasetResponse'] = _VALIDATEDATASETRESPONSE
DESCRIPTOR.message_types_by_name['SqlQueryRequest'] = _SQLQUERYREQUEST
DESCRIPTOR.message_types_by_name['SqlQueryResponse'] = _SQLQUERYRESPONSE
DESCRIPTOR.message_types_by_name['SqlQueryInProgress'] = _SQLQUERYINPROGRESS
DESCRIPTOR.message_types_by_name['SqlQueryFinished'] = _SQLQUERYFINISHED
DESCRIPTOR.message_types_by_name['JobStatusRequest'] = _JOBSTATUSREQUEST
DESCRIPTOR.message_types_by_name['JobStatusResponse'] = _JOBSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetResultsRequest'] = _GETRESULTSREQUEST
DESCRIPTOR.message_types_by_name['RetrieveDataRoomRequest'] = _RETRIEVEDATAROOMREQUEST
DESCRIPTOR.message_types_by_name['RetrieveDataRoomResponse'] = _RETRIEVEDATAROOMRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveAuditLogRequest'] = _RETRIEVEAUDITLOGREQUEST
DESCRIPTOR.message_types_by_name['RetrieveAuditLogResponse'] = _RETRIEVEAUDITLOGRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusRequest'] = _RETRIEVEDATAROOMSTATUSREQUEST
DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusResponse'] = _RETRIEVEDATAROOMSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusRequest'] = _UPDATEDATAROOMSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusResponse'] = _UPDATEDATAROOMSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetRequest'] = _RETRIEVEPUBLISHEDDATASETREQUEST
DESCRIPTOR.message_types_by_name['PublishedDataset'] = _PUBLISHEDDATASET
DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetResponse'] = _RETRIEVEPUBLISHEDDATASETRESPONSE
DESCRIPTOR.message_types_by_name['RemovePublishedDatasetRequest'] = _REMOVEPUBLISHEDDATASETREQUEST
DESCRIPTOR.message_types_by_name['RemovePublishedDatasetResponse'] = _REMOVEPUBLISHEDDATASETRESPONSE
DESCRIPTOR.message_types_by_name['ValidateQueriesRequest'] = _VALIDATEQUERIESREQUEST
DESCRIPTOR.message_types_by_name['QuerySchemas'] = _QUERYSCHEMAS
DESCRIPTOR.message_types_by_name['ValidateQueriesResponse'] = _VALIDATEQUERIESRESPONSE
DESCRIPTOR.message_types_by_name['EncryptionKey'] = _ENCRYPTIONKEY
DESCRIPTOR.message_types_by_name['TableSchema'] = _TABLESCHEMA
DESCRIPTOR.message_types_by_name['NamedColumn'] = _NAMEDCOLUMN
DESCRIPTOR.message_types_by_name['DatasetManifest'] = _DATASETMANIFEST
DESCRIPTOR.enum_types_by_name['DataRoomStatus'] = _DATAROOMSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WaterfrontRequest = _reflection.GeneratedProtocolMessageType('WaterfrontRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATERFRONTREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.WaterfrontRequest)
  })
_sym_db.RegisterMessage(WaterfrontRequest)

WaterfrontResponse = _reflection.GeneratedProtocolMessageType('WaterfrontResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATERFRONTRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.WaterfrontResponse)
  })
_sym_db.RegisterMessage(WaterfrontResponse)

AuthenticationData = _reflection.GeneratedProtocolMessageType('AuthenticationData', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATIONDATA,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.AuthenticationData)
  })
_sym_db.RegisterMessage(AuthenticationData)

CreateDataRoomRequest = _reflection.GeneratedProtocolMessageType('CreateDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.CreateDataRoomRequest)
  })
_sym_db.RegisterMessage(CreateDataRoomRequest)

CreateDataRoomResponse = _reflection.GeneratedProtocolMessageType('CreateDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.CreateDataRoomResponse)
  })
_sym_db.RegisterMessage(CreateDataRoomResponse)

DataRoomValidationError = _reflection.GeneratedProtocolMessageType('DataRoomValidationError', (_message.Message,), {
  'DESCRIPTOR' : _DATAROOMVALIDATIONERROR,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.DataRoomValidationError)
  })
_sym_db.RegisterMessage(DataRoomValidationError)

PublishDatasetToDataRoomRequest = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.PublishDatasetToDataRoomRequest)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomRequest)

PublishDatasetToDataRoomResponse = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.PublishDatasetToDataRoomResponse)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomResponse)

ValidateDatasetRequest = _reflection.GeneratedProtocolMessageType('ValidateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATASETREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.ValidateDatasetRequest)
  })
_sym_db.RegisterMessage(ValidateDatasetRequest)

ValidateDatasetFailure = _reflection.GeneratedProtocolMessageType('ValidateDatasetFailure', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATASETFAILURE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.ValidateDatasetFailure)
  })
_sym_db.RegisterMessage(ValidateDatasetFailure)

ValidateDatasetResponse = _reflection.GeneratedProtocolMessageType('ValidateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATASETRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.ValidateDatasetResponse)
  })
_sym_db.RegisterMessage(ValidateDatasetResponse)

SqlQueryRequest = _reflection.GeneratedProtocolMessageType('SqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.SqlQueryRequest)
  })
_sym_db.RegisterMessage(SqlQueryRequest)

SqlQueryResponse = _reflection.GeneratedProtocolMessageType('SqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.SqlQueryResponse)
  })
_sym_db.RegisterMessage(SqlQueryResponse)

SqlQueryInProgress = _reflection.GeneratedProtocolMessageType('SqlQueryInProgress', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYINPROGRESS,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.SqlQueryInProgress)
  })
_sym_db.RegisterMessage(SqlQueryInProgress)

SqlQueryFinished = _reflection.GeneratedProtocolMessageType('SqlQueryFinished', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYFINISHED,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.SqlQueryFinished)
  })
_sym_db.RegisterMessage(SqlQueryFinished)

JobStatusRequest = _reflection.GeneratedProtocolMessageType('JobStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.JobStatusRequest)
  })
_sym_db.RegisterMessage(JobStatusRequest)

JobStatusResponse = _reflection.GeneratedProtocolMessageType('JobStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.JobStatusResponse)
  })
_sym_db.RegisterMessage(JobStatusResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.GetResultsRequest)
  })
_sym_db.RegisterMessage(GetResultsRequest)

RetrieveDataRoomRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RetrieveDataRoomRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomRequest)

RetrieveDataRoomResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RetrieveDataRoomResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomResponse)

RetrieveAuditLogRequest = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RetrieveAuditLogRequest)
  })
_sym_db.RegisterMessage(RetrieveAuditLogRequest)

RetrieveAuditLogResponse = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RetrieveAuditLogResponse)
  })
_sym_db.RegisterMessage(RetrieveAuditLogResponse)

RetrieveDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RetrieveDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusRequest)

RetrieveDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RetrieveDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusResponse)

UpdateDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.UpdateDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusRequest)

UpdateDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.UpdateDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusResponse)

RetrievePublishedDatasetRequest = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RetrievePublishedDatasetRequest)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetRequest)

PublishedDataset = _reflection.GeneratedProtocolMessageType('PublishedDataset', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHEDDATASET,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.PublishedDataset)
  })
_sym_db.RegisterMessage(PublishedDataset)

RetrievePublishedDatasetResponse = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RetrievePublishedDatasetResponse)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetResponse)

RemovePublishedDatasetRequest = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RemovePublishedDatasetRequest)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetRequest)

RemovePublishedDatasetResponse = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.RemovePublishedDatasetResponse)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetResponse)

ValidateQueriesRequest = _reflection.GeneratedProtocolMessageType('ValidateQueriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEQUERIESREQUEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.ValidateQueriesRequest)
  })
_sym_db.RegisterMessage(ValidateQueriesRequest)

QuerySchemas = _reflection.GeneratedProtocolMessageType('QuerySchemas', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSCHEMAS,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.QuerySchemas)
  })
_sym_db.RegisterMessage(QuerySchemas)

ValidateQueriesResponse = _reflection.GeneratedProtocolMessageType('ValidateQueriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEQUERIESRESPONSE,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.ValidateQueriesResponse)
  })
_sym_db.RegisterMessage(ValidateQueriesResponse)

EncryptionKey = _reflection.GeneratedProtocolMessageType('EncryptionKey', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTIONKEY,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.EncryptionKey)
  })
_sym_db.RegisterMessage(EncryptionKey)

TableSchema = _reflection.GeneratedProtocolMessageType('TableSchema', (_message.Message,), {
  'DESCRIPTOR' : _TABLESCHEMA,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.TableSchema)
  })
_sym_db.RegisterMessage(TableSchema)

NamedColumn = _reflection.GeneratedProtocolMessageType('NamedColumn', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDCOLUMN,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.NamedColumn)
  })
_sym_db.RegisterMessage(NamedColumn)

DatasetManifest = _reflection.GeneratedProtocolMessageType('DatasetManifest', (_message.Message,), {
  'DESCRIPTOR' : _DATASETMANIFEST,
  '__module__' : 'waterfront_pb2'
  # @@protoc_insertion_point(class_scope:waterfront.DatasetManifest)
  })
_sym_db.RegisterMessage(DatasetManifest)


# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import column_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CsvTableFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COLUMNTYPES_FIELD_NUMBER: builtins.int

    @property
    def columnTypes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[column_type_pb2.ColumnType]: ...

    def __init__(self,
        *,
        columnTypes : typing.Optional[typing.Iterable[column_type_pb2.ColumnType]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"columnTypes",b"columnTypes"]) -> None: ...
global___CsvTableFormat = CsvTableFormat
